@@ -358,7 +358,7 @@ help_cb (GtkAction *action, GtkWidget *callback_data)
                                                                                 
         if (error != NULL) {
                 gconf_editor_window_popup_error_dialog (GTK_WINDOW (GCONF_EDITOR_WINDOW (callback_data)),
-                                                        _("Couldn't display help: %s"), error->message);
+                                                        _("Couldn't display help: %s"), error);
         }
 }
 
@@ -413,8 +413,11 @@ gconf_editor_popup_window_unset_key (GtkAction *action, GtkWidget *callback_data
 	gchar *key;
 	GError *error = NULL;
 	
-	gtk_tree_selection_get_selected (gtk_tree_view_get_selection (GTK_TREE_VIEW (window->list_view)),
-					 NULL, &iter);
+	if (!gtk_tree_selection_get_selected (gtk_tree_view_get_selection (GTK_TREE_VIEW (window->list_view)),
+					 NULL, &iter)) {
+		return;
+	}
+
 	gtk_tree_model_get (window->sorted_list_model, &iter,
 			    GCONF_LIST_MODEL_KEY_PATH_COLUMN, &key,
 			    -1);
@@ -896,6 +899,10 @@ list_view_button_press_event (GtkTreeView *tree_view, GdkEventButton *event, GCo
 						  TRUE);
 			gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/UnsetKey"), 
 						  TRUE);
+			gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/DefaultKey"), 
+						  TRUE);
+			gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/MandatoryKey"), 
+						  TRUE);
 			
 			gtk_tree_path_free (path);
 		}
@@ -904,6 +911,10 @@ list_view_button_press_event (GtkTreeView *tree_view, GdkEventButton *event, GCo
 						  FALSE);
 			gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/UnsetKey"), 
 						  FALSE);
+			gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/DefaultKey"), 
+						  FALSE);
+			gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/MandatoryKey"), 
+						  FALSE);
 
 		}
 		
@@ -980,6 +991,33 @@ gconf_editor_window_list_view_popup_position (GtkMenu   *menu G_GNUC_UNUSED,
 static void
 gconf_editor_window_list_view_popup_menu (GtkWidget *widget, GConfEditorWindow *window)
 {
+	GtkTreeIter iter;
+
+	GtkTreeSelection *selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (window->list_view));
+	/* Select our row */
+	if (gtk_tree_selection_get_selected (selection, &window->list_model, &iter)) {
+		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/EditKey"), 
+					  TRUE);
+		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/UnsetKey"), 
+					  TRUE);
+		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/DefaultKey"), 
+					  TRUE);
+		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/MandatoryKey"), 
+					  TRUE);
+			
+	}
+	else {
+		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/EditKey"), 
+					  FALSE);
+		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/UnsetKey"), 
+					  FALSE);
+		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/DefaultKey"), 
+					  FALSE);
+		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/MandatoryKey"), 
+					  FALSE);
+
+	}
+	
 	gtk_menu_popup (GTK_MENU (window->popup_menu), NULL, NULL,
 			(GtkMenuPositionFunc) gconf_editor_window_list_view_popup_position, 
 			widget->window,
